AddresssAutocompleteStatefulWidget class
abstract
Properties
androidCertSha1Fingerprint
→ String ?
Optional — the SHA-1 signing-certificate fingerprint registered for
your Android app in the Google Cloud console, sent as X-Android-Cert.
final
androidPackageName
→ String ?
Optional — your Android applicationId, sent as the X-Android-Package
header so Android-app-restricted API keys work. Use together with
androidCertSha1Fingerprint .
final
apiVersion
→ PlacesApiVersion
Which Google Places backend to use. Defaults to
PlacesApiVersion.placesApiNew ; pass PlacesApiVersion.legacy to keep
using the legacy Places API on Google Cloud projects where it is still
enabled. Ignored when placeApiProvider is supplied.
final
autofocus
→ bool
final
buildItem
→ Widget Function(Suggestion , int ) ?
builder used to render each item displayed
must not be null
final
clearButton
→ Icon ?
builder used to render a clear, it can be null, but in that case, a clear button is not displayed
final
componentCountry
→ String ?
used to narrow down address search
final
controller
→ TextEditingController ?
final
debounceTime
→ int
debounce time in milliseconds (default 600)
final
decoration
→ InputDecoration ?
final
elevation
→ double ?
Elevation for the suggestion list
final
expands
→ bool
final
focusNode
→ FocusNode ?
final
hashCode
→ int
The hash code for this object.
no setter inherited
hoverColor
→ Color ?
Hover color around buildItem widget on desktop platforms.
final
initialValue
→ String ?
final
iosBundleId
→ String ?
Optional — your iOS bundle identifier, sent as
X-Ios-Bundle-Identifier so iOS-app-restricted API keys work.
final
key
→ Key ?
Controls how one widget replaces another widget in the tree.
final inherited
keyboardType
→ TextInputType ?
final
language
→ String ?
Inform Google places of desired language the results should be returned.
final
mapsApiKey
→ String ?
Your Google Maps API key. Required unless a custom placeApiProvider
is supplied (in which case the built-in backends — and this key — are
not used).
final
maxLength
→ int ?
final
maxLengthEnforcement
→ MaxLengthEnforcement ?
final
maxLines
→ int ?
final
minLines
→ int ?
final
onChanged
→ ValueChanged <String > ?
final
onClearClick
→ void Function() ?
Callback triggered when user clicks clear icon. This can be useful if the caller wants to clear other
address fields that may be in their form.
final
onFinishedEditingWithNoSuggestion
→ ValueChanged <String > ?
final
onInitialSuggestionClick
→ void Function(Suggestion suggestion ) ?
Callback triggered when a address item is selected, allows chance to
clear other fields awaiting Place details in onSuggestionClick
or to use the Suggestion information directly.
final
onSuggestionClick
→ void Function(Place place ) ?
Callback triggered when after Place has been retreived after item is selected
final
onSuggestionClickGetTextToUseForControl
→ String ? Function(Place place ) ?
Callback triggered when a
item is selected
final
overlayOffset
→ double
Offset between the TextField and the Overlay
final
placeApiProvider
→ PlaceApiProvider ?
Optional custom backend (native SDK wrapper, backend proxy, test fake).
When supplied, apiVersion , mapsApiKey and the built-in providers are
not used for API calls.
final
postalCodeLookup
→ bool ?
(deprecated) PostalCode lookup instead of address lookup (defaults to false)
(This has now been deprecated and replaced with type parameter type:AutoCompleteType.postalCode).
final
prepareQuery
→ String Function(String address ) ?
Callback triggered before sending query to google places API.
This allows the caller to prepare the query, modifying it in any way. It might be
used for adding things like City, State, Zip that may be already entered in other
form elements.
final
readOnly
→ bool
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
selectionColor
→ Color ?
Selection color around buildItem widget on desktop platforms.
final
showCursor
→ bool ?
final
showGoogleTradeMark
→ bool
if true, shows "powered by google" inside the suggestion list, after its items
final
strutStyle
→ StrutStyle ?
final
style
→ TextStyle ?
final
suggestionsOverlayDecoration
→ BoxDecoration ?
BoxDecoration for the suggestions external container
final
textAlign
→ TextAlign
final
textAlignVertical
→ TextAlignVertical ?
final
textCapitalization
→ TextCapitalization
final
textDirection
→ TextDirection ?
final
textInputAction
→ TextInputAction ?
final
type
→ AutoCompleteType ?
Single AutoCompleteType enum for type of information to autocomplete
(Defaults to AutoCompleteType.address , use AutoCompleteType.postalCode for Zipcode lookup)
This must be null if types is supplied
final
types
→ List <AutoCompleteType > ?
Can be used as an alternative to type and allows a list of up to 5 AutoCompleteType enums
to specify the types of autocomplete information to lookup.
(Google places api only allows 5 types maximum)
(type must not be supplied if types is used).
final
google_maps_places_autocomplete_widgets 2.1.1