PlacesApiVersion enum
Selects which Google Places backend the autocomplete widgets use.
Values
- placesApiNew → const PlacesApiVersion
-
Places API (New) —
https://places.googleapis.com/v1. The default. Requires "Places API (New)" to be enabled for your API key in the Google Cloud console. - legacy → const PlacesApiVersion
-
The legacy Places API —
https://maps.googleapis.com/maps/api/place. Google set this API to legacy status on March 1, 2025: it can no longer be enabled on new Google Cloud projects, but keeps working on projects where it was already enabled.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PlacesApiVersion> - A constant List of the values in this enum, in order of their declaration.